@@ -10,4 +10,4 @@ if __name__ == "__main__":
     prs = prs.parse_args()
 
     # We execute the zm method
-    Ziim().zm(prs.command)
+    Ziim().zm(str(prs.command))
